@@ -104,10 +104,14 @@ class Spec:
     def fill_spec_info(self):
         """ Fills the different variable required for the spec file. """
         self.log.info('Filling spec variable from info collected')
+
+        self.__dict['modname'] = self.package.name
+        self.__dict['barename'] = self.package.name.replace('.', '-')
         if self.package.name.startswith('python-'):
-            self.__dict['name'] = self.package.name
+            self.__dict['name'] = self.__dict['barename']
         else:
-            self.__dict['name'] = 'python-%s' % self.package.name
+            self.__dict['name'] = 'python-%s' % self.__dict['barename']
+
         self.__dict['arch'] = self.package.arch
         self.__dict['version'] = self.package.version
         self.__dict['summary'] = self.package.summary
@@ -130,9 +134,9 @@ class Spec:
         """
         specdir = get_rpm_tag('_specdir')
         if self.package.name.startswith('python-'):
-            specname = '%s.spec' % self.package.name
+            specname = '%s.spec' % self.__dict['barename'].lower()
         else:
-            specname = 'python-%s.spec' % self.package.name
+            specname = 'python-%s.spec' % self.__dict['barename'].lower()
         return '%s/%s' % (specdir, specname)
 
     def read_specfile(self):
@@ -172,7 +176,7 @@ class Spec:
         self.log.info('Writing file %s' % specfile)
         try:
             stream = open(specfile, 'w')
-            stream.write(self.spec)
+            stream.write(self.spec.encode('utf-8'))
             stream.close()
             self.log.debug('Spec file writen: %s' % specfile)
             print 'Spec file writen: %s' % specfile
